==> breeze_website_builder_6.5.02.tar.gz: manage/plugins/lang/gallery/ca.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Administrar paràmetres taula de llum gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "director del Gallery");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Image Ample");
define('MANAGE_GALLERY_FULL_HEIGHT', "Veure la Imatge Alçada");
define('MANAGE_GALLERY_THUMB_WIDTH', "Ample de la imatge en miniatura");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Imatge en miniatura Alçada");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Polze preservar la relació d&#39;aspecte");
define('MANAGE_GALLERY_SHOW_TITLES', "Mostra títols");
define('MANAGE_GALLERY_DISABLE_SORT', "desactivar Ordenar");
define('MANAGE_GALLERY_DELETE_IMAGE', "eliminar imatge");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Guardar l&#39;ordre de classificació");
define('MANAGE_GALLERY_PUBLISH_MSG', "Feu clic a &quot;Actualitzar&quot; per a publicar <br /> imatges carregades.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Totes les imatges han estat redimensionada i configuració s&#39;ha desat.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Hi va haver un error en canviar la mida de les imatges o desar la configuració.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "La seva imatge (s) s&#39;ha carregat.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "S&#39;ha produït un error en pujar la imatge (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "L&#39;arxiu que està intentant carregar no és una imatge.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "L&#39;arxiu que està tractant de pujar és massa gran.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "El títol s&#39;ha desat.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Esteu segur que voleu esborrar la imatge");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "La imatge ha estat esborrada.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "S&#39;ha produït un error en eliminar la imatge.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Memorització dels paràmetres i canviar la mida de les imatges, si us plau esperi ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Carregant, si us plau esperi ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "L&#39;ordre de classificació no s&#39;ha guardat. Vols guardar l&#39;ordre de classificació?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "L&#39;ordre de les imatges espècie s&#39;ha desat.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "S&#39;ha produït un error en desar el tipus d&#39;imatge.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/ca.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Administrar paràmetres taula de llum gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "director del Gallery");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Image Ample");
define('MANAGE_GALLERY_FULL_HEIGHT', "Veure la Imatge Alçada");
define('MANAGE_GALLERY_THUMB_WIDTH', "Ample de la imatge en miniatura");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Imatge en miniatura Alçada");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Polze preservar la relació d&#39;aspecte");
define('MANAGE_GALLERY_SHOW_TITLES', "Mostra títols");
define('MANAGE_GALLERY_DISABLE_SORT', "desactivar Ordenar");
define('MANAGE_GALLERY_DELETE_IMAGE', "eliminar imatge");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Guardar l&#39;ordre de classificació");
define('MANAGE_GALLERY_PUBLISH_MSG', "Feu clic a &quot;Actualitzar&quot; per a publicar <br /> imatges carregades.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Totes les imatges han estat redimensionada i configuració s&#39;ha desat.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Hi va haver un error en canviar la mida de les imatges o desar la configuració.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "La seva imatge (s) s&#39;ha carregat.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "S&#39;ha produït un error en pujar la imatge (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "L&#39;arxiu que està intentant carregar no és una imatge.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "L&#39;arxiu que està tractant de pujar és massa gran.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "El títol s&#39;ha desat.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Esteu segur que voleu esborrar la imatge");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "La imatge ha estat esborrada.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "S&#39;ha produït un error en eliminar la imatge.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Memorització dels paràmetres i canviar la mida de les imatges, si us plau esperi ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Carregant, si us plau esperi ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "L&#39;ordre de classificació no s&#39;ha guardat. Vols guardar l&#39;ordre de classificació?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "L&#39;ordre de les imatges espècie s&#39;ha desat.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "S&#39;ha produït un error en desar el tipus d&#39;imatge.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "El fitxer que intenteu carregar és més gran que la configuració PHP de &quot;upload_max_filesize&quot; o de &quot;post_max_size&quot;. Poseu-vos en contacte amb l&#39;administrador del sistema per augmentar aquests límits.");
?>
